import Vue, { resolveComponent, openBlock, createBlock, withCtx, createVNode, createCommentVNode, renderSlot } from 'vue';
import { Dialog, Menu, MenuItem, Submenu, Input, InputNumber, Radio, RadioGroup, Select, Option, Button, ButtonGroup, Table, TableColumn, DatePicker, Form, FormItem, Tag, Row, Col, Upload, Card, Container, Header, Aside, Main, Dropdown, DropdownMenu, DropdownItem, Tooltip, Switch, Badge, Pagination, Tabs, TabPane, Loading, Checkbox, Message, Notification, MessageBox } from 'element-ui';
import '@/styles/element-variables.scss';
import VJsoneditor from 'v-jsoneditor';
import '@/styles/common.scss';
import '@/styles/icons.scss';
import { __decorate } from 'tslib';
import { Vue as Vue$1, Prop, Component } from 'vue-property-decorator';

Vue.use(Dialog);
Vue.use(Menu);
Vue.use(MenuItem);
Vue.use(Submenu);
Vue.use(Input);
Vue.use(InputNumber);
Vue.use(Radio);
Vue.use(RadioGroup);
Vue.use(Select);
Vue.use(Option);
Vue.use(Button);
Vue.use(ButtonGroup);
Vue.use(Table);
Vue.use(TableColumn);
Vue.use(DatePicker);
Vue.use(Form);
Vue.use(FormItem);
Vue.use(Tag);
Vue.use(Row);
Vue.use(Col);
Vue.use(Upload);
Vue.use(Card);
Vue.use(Container);
Vue.use(Header);
Vue.use(Aside);
Vue.use(Main);
Vue.use(Dropdown);
Vue.use(DropdownMenu);
Vue.use(DropdownItem);
Vue.use(Tooltip);
Vue.use(Switch);
Vue.use(Badge);
Vue.use(Pagination);
Vue.use(Tabs);
Vue.use(TabPane);
Vue.use(Loading.directive);
Vue.use(Checkbox);
const MsgBox = MessageBox;
Vue.prototype.$prompt = MsgBox.prompt;
Vue.prototype.$alert = MsgBox.alert;
Vue.prototype.$message = Message;
Vue.prototype.$notify = Notification;
// locale.use(lang)

Vue.use(VJsoneditor);

var Size;
(function (Size) {
    Size["BIG"] = "big";
    Size["MEDIUM"] = "medium";
    Size["SMALL"] = "small";
})(Size || (Size = {}));

var ButtonTypes;
(function (ButtonTypes) {
    ButtonTypes["PRIMARY"] = "primary";
    ButtonTypes["SECONDARY"] = "secondary";
    ButtonTypes["TERTIARY"] = "tertiary";
    ButtonTypes["DELETE"] = "delete";
})(ButtonTypes || (ButtonTypes = {}));
var ButtonNativeTypes;
(function (ButtonNativeTypes) {
    ButtonNativeTypes["BUTTON"] = "button";
    ButtonNativeTypes["SUBMIT"] = "submit";
    ButtonNativeTypes["RESET"] = "reset";
})(ButtonNativeTypes || (ButtonNativeTypes = {}));
const ButtonSize = Size;

//
let MyButton = class MyButton extends Vue$1 {
    constructor() {
        super(...arguments);
        this.ButtonTypes = ButtonTypes;
        this.elementIcon = '';
    }
    get computedSize() {
        if (this.size === ButtonSize.BIG ||
            !Object.values(ButtonSize).includes(this.size)) {
            return '';
        }
        return this.size;
    }
    get computedType() {
        if (this.type === ButtonTypes.PRIMARY) {
            return this.type;
        }
        return 'plain';
    }
    get computedClasses() {
        const cssClasses = [];
        if (Object.values(ButtonSize).includes(this.size)) {
            cssClasses.push(this.size);
        }
        if (Object.values(ButtonTypes).includes(this.type)) {
            cssClasses.push(this.type);
        }
        if (this.isLoading) {
            cssClasses.push('loading');
        }
        return cssClasses;
    }
    get availableIcon() {
        if (!this.icon) {
            return '';
        }
        if (this.icon.startsWith('el-')) {
            this.elementIcon = this.icon;
            return '';
        }
        // TODO: add checks for invalid icons
        this.elementIcon = '';
        return `icon-${this.icon}`;
    }
    get isLoading() {
        if (this.type === ButtonTypes.TERTIARY) {
            return false;
        }
        return this.loading;
    }
    handleClick() {
        this.$emit('click');
    }
};
__decorate([
    Prop({ default: ButtonTypes.PRIMARY, type: String })
], MyButton.prototype, "type", void 0);
__decorate([
    Prop({ default: ButtonSize.BIG, type: String })
], MyButton.prototype, "size", void 0);
__decorate([
    Prop({ default: '', type: String })
], MyButton.prototype, "icon", void 0);
__decorate([
    Prop({ default: false, type: Boolean })
], MyButton.prototype, "disabled", void 0);
__decorate([
    Prop({ default: false, type: Boolean })
], MyButton.prototype, "loading", void 0);
__decorate([
    Prop({ default: false, type: Boolean })
], MyButton.prototype, "autofocus", void 0);
__decorate([
    Prop({ default: '', type: String })
], MyButton.prototype, "tooltip", void 0);
__decorate([
    Prop({ default: ButtonNativeTypes.BUTTON, type: String })
], MyButton.prototype, "nativeType", void 0);
MyButton = __decorate([
    Component
], MyButton);
var script = MyButton;

function render(_ctx, _cache) {
  const _component_el_button = resolveComponent("el-button");
  const _component_el_tooltip = resolveComponent("el-tooltip");

  return (openBlock(), createBlock(_component_el_tooltip, {
    content: _ctx.tooltip,
    placement: "right",
    disabled: !_ctx.tooltip
  }, {
    default: withCtx(() => [
      createVNode(_component_el_button, {
        type: _ctx.computedType,
        "native-type": _ctx.nativeType,
        size: _ctx.computedSize,
        class: _ctx.computedClasses,
        disabled: _ctx.disabled,
        loading: _ctx.isLoading,
        autofocus: _ctx.autofocus,
        circle: _ctx.type === _ctx.ButtonTypes.TERTIARY,
        icon: _ctx.elementIcon,
        onClick: _cache[1] || (_cache[1] = $event => (_ctx.handleClick($event)))
      }, {
        default: withCtx(() => [
          (_ctx.availableIcon)
            ? (openBlock(), createBlock("i", {
                key: 0,
                class: [_ctx.availableIcon]
              }, null, 2 /* CLASS */))
            : createCommentVNode("v-if", true),
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 1
      }, 8 /* PROPS */, ["type", "native-type", "size", "class", "disabled", "loading", "autofocus", "circle", "icon"])
    ]),
    _: 1
  }, 8 /* PROPS */, ["content", "disabled"]))
}

script.render = render;
script.__file = "src/components/Button/MyButton.vue";

function render$1(_ctx, _cache) {
  const _component_el_button_group = resolveComponent("el-button-group");

  return (openBlock(), createBlock(_component_el_button_group, null, {
    default: withCtx(() => [
      renderSlot(_ctx.$slots, "default")
    ]),
    _: 1
  }))
}

const script$1 = {};


script$1.render = render$1;
script$1.__file = "src/components/Button/MyButtonGroup.vue";

[script, script$1].forEach(element => {
    element.install = function (Vue) {
        Vue.component(element.name, element);
    };
});

const components = [
    script,
    script$1
];
const install = function (Vue, opts = {}) {
    components.forEach(component => {
        Vue.component(component.name, component);
    });
};
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}
var index = {
    install,
    MyButton: script,
    MyButtonGroup: script$1
};

export default index;
//# sourceMappingURL=test-ui-ts-lib.esm.js.map
